@@ -135,6 +135,10 @@ class MainLog(BaseLog):
                         req_agent = request.headers.environ['HTTP_USER_AGENT']
                         response_time = datetime.datetime.now()
                         com_name = request.headers.environ['HTTP_HOST']  # + ":" + request.environ['']#主机名
+                        if not isinstance(request_content, unicode):
+                            request_content = unicode(request_content, 'utf-8')
+                        if not isinstance(response_content, unicode):
+                            response_content = unicode(response_content, 'utf-8')
                         message = {u'actionCode': action_code,
                                    u'requestTime': request_time.strftime("%Y-%m-%d %H:%M:%S"),
                                    u'responseTime': response_time.strftime("%Y-%m-%d %H:%M:%S"),
